@@ -75,17 +75,34 @@ class CellularAutomatonCreator(abc.ABC):
 
 
 class CellularAutomaton(CellularAutomatonCreator, abc.ABC):
-    """
-    This class represents a cellular automaton.
+    """ This class represents a cellular automaton.
     It can be created with n dimensions and can handle different neighborhood definitions.
 
-    :param dimension:       Iterable of len = dimensions
-                            (e.g. [4, 3, 3, 3] = 4 x 3 x 3 x 3 cells in a four dimensional cube).
-    :param neighborhood:    Defines which cells are considered neighbors.
+    It is intended to be uses as base class.
+    Override `init_cell_state()` to define the state the cell(s) are initiated with.
+    Override `evolve()` to define the rule that is aplied on every evolution step of this automaton.
     """
     def __init__(self, neighborhood: Neighborhood, *args, **kwargs):
+        """ Initiates a cellular automaton by the use of the `init_cell_state` method.
+        :param neighborhood: Defines which cells are considered neighbors.
+        :param dimension: Iterable of len = dimensions
+                          (e.g. [4, 3, 3, 3] = 4 x 3 x 3 x 3 cells in a four dimensional cube).
+        """
         super().__init__(neighborhood=neighborhood, *args, **kwargs)
         self._evolution_step = 0
+        self._active = True
+
+    def is_active(self):
+        return self._active
+
+    def reactivate(self):
+        """ Sets all cells active again """
+        for cell in self._current_state.values():
+            cell.is_active = True
+            cell.is_dirty = True
+        self._active = True
+
+    active = property(is_active)
 
     def get_cells(self):
         return self._current_state
@@ -109,6 +126,7 @@ class CellularAutomaton(CellularAutomatonCreator, abc.ABC):
         :param times: The number of evolution steps processed with one call of this method.
         """
         for _ in itertools.repeat(None, times):
+            self._active = False
             self.__evolve_cells(self._current_state, self._next_state)
             self._current_state, self._next_state = self._next_state, self._current_state
             self._evolution_step += 1
@@ -118,16 +136,16 @@ class CellularAutomaton(CellularAutomatonCreator, abc.ABC):
         evolution_rule = self.evolve_rule
         for old, new in zip(this_state.values(), next_state.values()):
             if old.is_active:
-                new_state = evolution_rule(old.state, [n.state for n in old.neighbors])
+                new_state = evolution_rule(old.state.copy(), [n.state for n in old.neighbors])
                 old.is_active = False
                 evolve_cell(old, new, new_state)
 
-    @classmethod
-    def __evolve_cell(cls, old, cell, new_state):
-        changed = new_state != cell.state
+    def __evolve_cell(self, old, cell, new_state):
+        changed = new_state != old.state
         cell.state = new_state
         cell.is_dirty |= changed
         old.is_dirty |= changed
+        self._active |= changed
         if changed:
             cell.is_active = True
             for n in cell.neighbors:
