@@ -33,7 +33,7 @@ class StarFallAutomaton(CellularAutomaton):
     """ Represents an automaton dropping colorful stars """
 
     def __init__(self):
-        super().__init__(dimension=[100, 100],
+        super().__init__(dimension=[200, 200],
                          neighborhood=MooreNeighborhood(EdgeRule.FIRST_AND_LAST_CELL_OF_DIMENSION_ARE_NEIGHBORS))
 
     def init_cell_state(self, __) -> Sequence:
@@ -52,4 +52,6 @@ def state_to_color(current_state: Sequence) -> Sequence:
 
 
 if __name__ == "__main__":
-    CAWindow(cellular_automaton=StarFallAutomaton(), state_to_color_cb=state_to_color).run()
+    CAWindow(cellular_automaton=StarFallAutomaton(),
+             window_size=(1000, 830),
+             state_to_color_cb=state_to_color).run()
